==> qalculate-kde_0.9.2.orig.tar.gz: qalculate-kde-0.9.2/src/qalculatepreferencesdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Niklas Knutsson   *
 *   nq@altern.org   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef QALCULATEPREFERENCESDIALOG_H
#define QALCULATEPREFERENCESDIALOG_H

#include <kdialogbase.h>

class QCheckBox;
class QRadioButton;
class QLabel;
class KFontRequester;
class KColorButton;

/**
@author Niklas Knutsson
*/
class QalculatePreferencesDialog : public KDialogBase {

	Q_OBJECT

public:

	QalculatePreferencesDialog(QWidget *parent = 0, const char *name = 0);
	virtual ~QalculatePreferencesDialog();

	bool editPreferences();

	QCheckBox *systrayButton, *statusButton, *iconsButton, *fetchExchangeRatesButton, *saveModeButton, *saveDefsButton, *unicodeButton, *lowerCaseButton, *lowerCaseEButton, *spellOutLogicalOperatorsButton, *useCustomResultFontButton, *useCustomExpressionFontButton, *useCustomStatusFontButton;
	QRadioButton *dotButton, *exButton, *asteriskButton, *divisionSlashButton, *divisionButton, *slashButton;
	QLabel *multiplicationLabel, *divisionLabel;
	KFontRequester *resultFontEdit, *expressionFontEdit, *statusFontEdit;
	KColorButton *statusErrorColorButton, *statusWarningColorButton;

protected slots:
	
	void slotApply();

};

#endif

==> qalculate-kde_0.9.4.orig.tar.gz: qalculate-kde-0.9.4/src/qalculatepreferencesdialog.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Niklas Knutsson   *
 *   nq@altern.org   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef QALCULATEPREFERENCESDIALOG_H
#define QALCULATEPREFERENCESDIALOG_H

#include <kdialogbase.h>

class QCheckBox;
class QRadioButton;
class QLabel;
class KFontRequester;
class KColorButton;

/**
@author Niklas Knutsson
*/
class QalculatePreferencesDialog : public KDialogBase {

	Q_OBJECT

public:

	QalculatePreferencesDialog(QWidget *parent = 0, const char *name = 0);
	virtual ~QalculatePreferencesDialog();

	bool editPreferences();

	QCheckBox *rpnKeypadOnlyButton, *systrayButton, *statusButton, *iconsButton, *fetchExchangeRatesButton, *saveModeButton, *saveDefsButton, *dotAsSeparatorButton, *unicodeButton, *lowerCaseButton, *lowerCaseEButton, *alternativeBasePrefixButton, *spellOutLogicalOperatorsButton, *useCustomResultFontButton, *useCustomExpressionFontButton, *useCustomStatusFontButton;
	QRadioButton *dotButton, *exButton, *asteriskButton, *divisionSlashButton, *divisionButton, *slashButton;
	QLabel *multiplicationLabel, *divisionLabel;
	KFontRequester *resultFontEdit, *expressionFontEdit, *statusFontEdit;
	KColorButton *statusErrorColorButton, *statusWarningColorButton;

protected slots:
	
	void slotApply();

};

#endif
